==> rest-assured-1.5-sources.jar: com/jayway/restassured/internal/RestAssuredResponseImpl.java <==
package com.jayway.restassured.internal;

import com.jayway.restassured.response.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class RestAssuredResponseImpl
  extends java.lang.Object  implements
    com.jayway.restassured.response.Response,    groovy.lang.GroovyObject {
public RestAssuredResponseImpl
() {}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getResponseHeaders() { return null;}
public  void setResponseHeaders(java.lang.Object value) { }
public  void setCookies(com.jayway.restassured.response.Cookies value) { }
public  java.lang.Object getContent() { return null;}
public  void setContent(java.lang.Object value) { }
public  void setContentType(java.lang.Object value) { }
public  void setStatusLine(java.lang.Object value) { }
public  void setStatusCode(java.lang.Object value) { }
public  java.lang.String getDefaultContentType() { return (java.lang.String)null;}
public  void setDefaultContentType(java.lang.String value) { }
public  com.jayway.restassured.internal.ResponseParserRegistrar getRpr() { return (com.jayway.restassured.internal.ResponseParserRegistrar)null;}
public  void setRpr(com.jayway.restassured.internal.ResponseParserRegistrar value) { }
public  boolean getHasExpectations() { return false;}
public  boolean isHasExpectations() { return false;}
public  void setHasExpectations(boolean value) { }
public  void parseResponse(java.lang.Object httpResponse, java.lang.Object content, java.lang.Object hasBodyAssertions, com.jayway.restassured.internal.ResponseParserRegistrar responseParserRegistrar) { }
public  java.lang.Object parseStatus(java.lang.Object httpResponse) { return null;}
public  java.lang.Object parseContentType(java.lang.Object httpResponse) { return null;}
public  java.lang.Object parseCookies() { return null;}
public  java.lang.Object parseHeaders(java.lang.Object httpResponse) { return null;}
public  java.lang.Object toString(groovy.lang.Writable node) { return null;}
public  java.lang.String print() { return (java.lang.String)null;}
public  java.lang.String asString() { return (java.lang.String)null;}
public  java.io.InputStream asInputStream() { return (java.io.InputStream)null;}
public  byte[] asByteArray() { return (byte[])null;}
public <T> T as(java.lang.Class<T> cls) { return null;}
public <T> T as(java.lang.Class<T> cls, com.jayway.restassured.mapper.ObjectMapper mapper) { return null;}
public  com.jayway.restassured.response.Cookies detailedCookies() { return (com.jayway.restassured.response.Cookies)null;}
public  com.jayway.restassured.response.Cookies getDetailedCookies() { return (com.jayway.restassured.response.Cookies)null;}
public  com.jayway.restassured.response.Cookie detailedCookie(java.lang.String name) { return (com.jayway.restassured.response.Cookie)null;}
public  com.jayway.restassured.response.Cookie getDetailedCookie(java.lang.String name) { return (com.jayway.restassured.response.Cookie)null;}
public  com.jayway.restassured.response.Response andReturn() { return (com.jayway.restassured.response.Response)null;}
public  com.jayway.restassured.response.ResponseBody body() { return (com.jayway.restassured.response.ResponseBody)null;}
public  com.jayway.restassured.response.Response thenReturn() { return (com.jayway.restassured.response.Response)null;}
public  com.jayway.restassured.response.ResponseBody getBody() { return (com.jayway.restassured.response.ResponseBody)null;}
public  com.jayway.restassured.response.Headers headers() { return (com.jayway.restassured.response.Headers)null;}
public  com.jayway.restassured.response.Headers getHeaders() { return (com.jayway.restassured.response.Headers)null;}
public  java.lang.String header(java.lang.String name) { return (java.lang.String)null;}
public  java.lang.String getHeader(java.lang.String name) { return (java.lang.String)null;}
public  java.util.Map<java.lang.String, java.lang.String> cookies() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public  java.util.Map<java.lang.String, java.lang.String> getCookies() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public  java.lang.String cookie(java.lang.String name) { return (java.lang.String)null;}
public  java.lang.String getCookie(java.lang.String name) { return (java.lang.String)null;}
public  java.lang.String contentType() { return (java.lang.String)null;}
public  java.lang.String getContentType() { return (java.lang.String)null;}
public  java.lang.String statusLine() { return (java.lang.String)null;}
public  int statusCode() { return (int)0;}
public  java.lang.String getStatusLine() { return (java.lang.String)null;}
public  int getStatusCode() { return (int)0;}
public  com.jayway.restassured.path.json.JsonPath jsonPath() { return (com.jayway.restassured.path.json.JsonPath)null;}
public  com.jayway.restassured.path.xml.XmlPath xmlPath() { return (com.jayway.restassured.path.xml.XmlPath)null;}
public <T> T path(java.lang.String path) { return null;}
}

==> rest-assured-1.7.2-sources.jar: com/jayway/restassured/internal/RestAssuredResponseImpl.java <==
package com.jayway.restassured.internal;

import com.jayway.restassured.response.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class RestAssuredResponseImpl
  extends java.lang.Object  implements
    com.jayway.restassured.response.Response,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getResponseHeaders() { return null;}
public  void setResponseHeaders(java.lang.Object value) { }
public  void setCookies(com.jayway.restassured.response.Cookies value) { }
public  java.lang.Object getContent() { return null;}
public  void setContent(java.lang.Object value) { }
public  void setContentType(java.lang.Object value) { }
public  void setStatusLine(java.lang.Object value) { }
public  void setStatusCode(java.lang.Object value) { }
public  java.lang.Object getSessionIdName() { return null;}
public  void setSessionIdName(java.lang.Object value) { }
public  java.lang.Object getConnectionManager() { return null;}
public  void setConnectionManager(java.lang.Object value) { }
public  java.lang.String getDefaultContentType() { return (java.lang.String)null;}
public  void setDefaultContentType(java.lang.String value) { }
public  com.jayway.restassured.internal.ResponseParserRegistrar getRpr() { return (com.jayway.restassured.internal.ResponseParserRegistrar)null;}
public  void setRpr(com.jayway.restassured.internal.ResponseParserRegistrar value) { }
public  java.lang.String getDefaultCharset() { return (java.lang.String)null;}
public  void setDefaultCharset(java.lang.String value) { }
public  boolean getHasExpectations() { return false;}
public  boolean isHasExpectations() { return false;}
public  void setHasExpectations(boolean value) { }
public  com.jayway.restassured.config.ObjectMapperConfig getObjectMapperConfig() { return (com.jayway.restassured.config.ObjectMapperConfig)null;}
public  void setObjectMapperConfig(com.jayway.restassured.config.ObjectMapperConfig value) { }
public  com.jayway.restassured.config.ConnectionConfig getConnectionConfig() { return (com.jayway.restassured.config.ConnectionConfig)null;}
public  void setConnectionConfig(com.jayway.restassured.config.ConnectionConfig value) { }
public  void parseResponse(java.lang.Object httpResponse, java.lang.Object content, java.lang.Object hasBodyAssertions, com.jayway.restassured.internal.ResponseParserRegistrar responseParserRegistrar) { }
public  java.lang.Object parseStatus(java.lang.Object httpResponse) { return null;}
public  java.lang.Object parseContentType(java.lang.Object httpResponse) { return null;}
public  java.lang.Object parseCookies() { return null;}
public  java.lang.Object parseHeaders(java.lang.Object httpResponse) { return null;}
public  java.lang.Object toString(groovy.lang.Writable node) { return null;}
public  java.lang.String print() { return (java.lang.String)null;}
public  java.lang.String prettyPrint() { return (java.lang.String)null;}
public  java.lang.String asString() { return (java.lang.String)null;}
public  java.io.InputStream asInputStream() { return (java.io.InputStream)null;}
public  byte[] asByteArray() { return (byte[])null;}
public <T> T as(java.lang.Class<T> cls) { return null;}
public <T> T as(java.lang.Class<T> cls, com.jayway.restassured.mapper.ObjectMapperType mapperType) { return null;}
public <T> T as(java.lang.Class<T> cls, com.jayway.restassured.mapper.ObjectMapper mapper) { return null;}
public  com.jayway.restassured.response.Cookies detailedCookies() { return (com.jayway.restassured.response.Cookies)null;}
public  com.jayway.restassured.response.Cookies getDetailedCookies() { return (com.jayway.restassured.response.Cookies)null;}
public  com.jayway.restassured.response.Cookie detailedCookie(java.lang.String name) { return (com.jayway.restassured.response.Cookie)null;}
public  com.jayway.restassured.response.Cookie getDetailedCookie(java.lang.String name) { return (com.jayway.restassured.response.Cookie)null;}
public  com.jayway.restassured.response.Response andReturn() { return (com.jayway.restassured.response.Response)null;}
public  com.jayway.restassured.response.ResponseBody body() { return (com.jayway.restassured.response.ResponseBody)null;}
public  com.jayway.restassured.response.Response thenReturn() { return (com.jayway.restassured.response.Response)null;}
public  com.jayway.restassured.response.ResponseBody getBody() { return (com.jayway.restassured.response.ResponseBody)null;}
public  com.jayway.restassured.response.Headers headers() { return (com.jayway.restassured.response.Headers)null;}
public  com.jayway.restassured.response.Headers getHeaders() { return (com.jayway.restassured.response.Headers)null;}
public  java.lang.String header(java.lang.String name) { return (java.lang.String)null;}
public  java.lang.String getHeader(java.lang.String name) { return (java.lang.String)null;}
public  java.util.Map<java.lang.String, java.lang.String> cookies() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public  java.util.Map<java.lang.String, java.lang.String> getCookies() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public  java.lang.String cookie(java.lang.String name) { return (java.lang.String)null;}
public  java.lang.String getCookie(java.lang.String name) { return (java.lang.String)null;}
public  java.lang.String contentType() { return (java.lang.String)null;}
public  java.lang.String getContentType() { return (java.lang.String)null;}
public  java.lang.String statusLine() { return (java.lang.String)null;}
public  int statusCode() { return (int)0;}
public  java.lang.String getStatusLine() { return (java.lang.String)null;}
public  java.lang.String sessionId() { return (java.lang.String)null;}
public  java.lang.String getSessionId() { return (java.lang.String)null;}
public  int getStatusCode() { return (int)0;}
public  com.jayway.restassured.path.json.JsonPath jsonPath() { return (com.jayway.restassured.path.json.JsonPath)null;}
public  com.jayway.restassured.path.xml.XmlPath xmlPath() { return (com.jayway.restassured.path.xml.XmlPath)null;}
public <T> T path(java.lang.String path) { return null;}
}
